@@ -110,6 +110,34 @@ class Ready(Response):
     def results(self):
         return self._results
 
+    @property
+    def flattened_values(self):
+        """
+        Obtain a dict or list containing all results, descending as deeply
+        as possible. One-to-one relations are flattened.
+        """
+
+        flattened_values = []
+        for r in self.results:
+            branch = {
+                self.name: r.value
+            }
+            if r.children:
+                for c in r.children:
+                    if isinstance(c, Ready):
+                        child_flat_values = c.flattened_values
+
+                        if isinstance(child_flat_values, dict):
+                            branch.update(child_flat_values)
+                        else:
+                            branch[c.name] = child_flat_values
+
+            flattened_values.append(branch)
+
+        if len(flattened_values) == 1:
+            return flattened_values[0]
+        else:
+            return flattened_values
 
 class DoneFind(Ready):
     """
